==> open-xchange-usm_6.22.1.orig.tar.bz2: open-xchange-usm-6.22.1/com.openexchange.usm.cache.ox_adapter/src/com/openexchange/usm/cache/ox_adapter/CacheManagerAdapter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.cache.ox_adapter;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;
import java.util.Properties;
import java.util.WeakHashMap;
import org.apache.commons.logging.Log;
import com.openexchange.caching.CacheService;
import com.openexchange.exception.OXException;
import com.openexchange.usm.cache.Cache;
import com.openexchange.usm.cache.CacheManager;

/**
 * Cache Manager Adaptor. Uses the OX Caching service.
 * @author ldo
 *
 */
public class CacheManagerAdapter implements CacheManager {

	// Keep track of Caches in use for profiling / debugging purposes
	private final Map<Cache<?, ?>, String> _cacheMap = Collections
			.synchronizedMap(new WeakHashMap<Cache<?, ?>, String>());

	private CacheService _cacheService;

	private Log _journal;

	public void activate(Log log, CacheService cacheService) {
		_journal = log;
		_cacheService = cacheService;
		_journal.info("USM->OX CacheManagerAdapter activated");
	}

	public void deactivate() {
		for (String cacheId : _cacheMap.values()) {
			try {
				_cacheService.freeCache(cacheId);
			} catch (OXException e) {
				_journal.error("Can not free cache: " + cacheId, e);
			}
		}
		_cacheMap.clear();
		_journal.info("USM->OX CacheManagerAdapter deactivated");
		_journal = null;
	}

	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
			Class<V> valueClass) {
		return createCache(id, keyClass, valueClass, null);
	}

	//TODO: do we want to configure our cache different than OX cache: loadConfiguration(?
	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
			Class<V> valueClass, Properties properties) {
		com.openexchange.caching.Cache cacheImpl;
		try {
			cacheImpl = _cacheService.getCache(id);
		} catch (OXException e) {
			_journal.error("Can not create cache: " + id, e);
			return null; //TODO: maybe throw exception
		}
		CacheAdapter<K, V> cache = new CacheAdapter<K, V>(cacheImpl, _journal);
		_cacheMap.put(cache, id);
		if (_journal.isDebugEnabled())
			_journal.debug("Created Cache " + id + ", " + _cacheMap.size() + " Caches active");
		return cache;
	}
}

==> open-xchange-usm_7.2.0.orig.tar.bz2: open-xchange-usm-7.2.0/com.openexchange.usm.cache.ox_adapter/src/com/openexchange/usm/cache/ox_adapter/CacheManagerAdapter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.cache.ox_adapter;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;
import java.util.Properties;
import java.util.WeakHashMap;
import org.apache.commons.logging.Log;
import com.openexchange.caching.CacheService;
import com.openexchange.exception.OXException;
import com.openexchange.usm.cache.Cache;
import com.openexchange.usm.cache.CacheManager;

/**
 * Cache Manager Adaptor. Uses the OX Caching service.
 * @author ldo
 *
 */
public class CacheManagerAdapter implements CacheManager {

	// Keep track of Caches in use for profiling / debugging purposes
	private final Map<Cache<?, ?>, String> _cacheMap = Collections
			.synchronizedMap(new WeakHashMap<Cache<?, ?>, String>());

	private CacheService _cacheService;

	private Log _journal;

	public void activate(Log log, CacheService cacheService) {
		_journal = log;
		_cacheService = cacheService;
		_journal.info("USM->OX CacheManagerAdapter activated");
	}

	public void deactivate() {
		for (String cacheId : _cacheMap.values()) {
			try {
				_cacheService.freeCache(cacheId);
			} catch (OXException e) {
				_journal.error("Can not free cache: " + cacheId, e);
			}
		}
		_cacheMap.clear();
		_journal.info("USM->OX CacheManagerAdapter deactivated");
		_journal = null;
	}

	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
			Class<V> valueClass) {
		return createCache(id, keyClass, valueClass, null);
	}

	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
			Class<V> valueClass, Properties properties) {
		com.openexchange.caching.Cache cacheImpl;
		try {
		    _cacheService.loadConfiguration(properties);
			cacheImpl = _cacheService.getCache(id);
		} catch (OXException e) {
			_journal.error("Can not create cache: " + id, e);
			return null; //TODO: maybe throw exception
		}
		CacheAdapter<K, V> cache = new CacheAdapter<K, V>(cacheImpl, _journal);
		_cacheMap.put(cache, id);
		if (_journal.isDebugEnabled())
			_journal.debug("Created Cache " + id + ", " + _cacheMap.size() + " Caches active");
		return cache;
	}
}
